==> estateplat-common-1.2.3-20180308.015314-39-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfJjhtJyqk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 经纪合同交易情况
 */
@Table(name = "ls_fcjy_clf_jjht_jyqk")
public class LsFcjyClfJjhtJyqk implements InsertVo {
    @Id
    private String id;//id
    private String jjhtid;//经纪合同id
    private String hbh;//户编号
    private Double nsjg;//拟售价格
    private String fkfs;//付款方式
    private String fkfsqt;//付款方式其他
    private String sfcd;//税费承担
    private String sfcdsm;//税费承担说明
    private Double zjfbl;//中介费比例
    private Double zjfjg;//中介费价格
    private Integer zjffkqx;//中介费付款期限
    private Double wyjbl;//违约金比例
    private Double wyj;//违约金
    private String zjfqtsm;//中介费其他说明

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public Double getNsjg() {
        return nsjg;
    }

    public void setNsjg(Double nsjg) {
        this.nsjg = nsjg;
    }

    public String getFkfs() {
        return fkfs;
    }

    public void setFkfs(String fkfs) {
        this.fkfs = fkfs;
    }

    public String getFkfsqt() {
        return fkfsqt;
    }

    public void setFkfsqt(String fkfsqt) {
        this.fkfsqt = fkfsqt;
    }

    public String getSfcd() {
        return sfcd;
    }

    public void setSfcd(String sfcd) {
        this.sfcd = sfcd;
    }

    public String getSfcdsm() {
        return sfcdsm;
    }

    public void setSfcdsm(String sfcdsm) {
        this.sfcdsm = sfcdsm;
    }

    public Double getZjfbl() {
        return zjfbl;
    }

    public void setZjfbl(Double zjfbl) {
        this.zjfbl = zjfbl;
    }

    public Double getZjfjg() {
        return zjfjg;
    }

    public void setZjfjg(Double zjfjg) {
        this.zjfjg = zjfjg;
    }

    public Integer getZjffkqx() {
        return zjffkqx;
    }

    public void setZjffkqx(Integer zjffkqx) {
        this.zjffkqx = zjffkqx;
    }

    public Double getWyjbl() {
        return wyjbl;
    }

    public void setWyjbl(Double wyjbl) {
        this.wyjbl = wyjbl;
    }

    public Double getWyj() {
        return wyj;
    }

    public void setWyj(Double wyj) {
        this.wyj = wyj;
    }

    public String getZjfqtsm() {
        return zjfqtsm;
    }

    public void setZjfqtsm(String zjfqtsm) {
        this.zjfqtsm = zjfqtsm;
    }
}

==> estateplat-common-1.2.4-20190823.030605-227-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfJjhtJyqk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 经纪合同交易情况
 */
@Table(name = "ls_fcjy_clf_jjht_jyqk")
public class LsFcjyClfJjhtJyqk implements InsertVo {
    @Id
    private String id;//id
    private String jjhtid;//经纪合同id
    private String hbh;//户编号
    private Double nsjg;//拟售价格
    private String fkfs;//付款方式
    private String fkfsqt;//付款方式其他
    private String sfcd;//税费承担
    private String sfcdsm;//税费承担说明
    private Double zjfbl;//中介费比例
    private Double zjfjg;//中介费价格
    private Integer zjffkqx;//中介费付款期限
    private Double wyjbl;//违约金比例
    private Double wyj;//违约金
    private String zjfqtsm;//中介费其他说明
    private Double nzjg;//拟租价格

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public Double getNsjg() {
        return nsjg;
    }

    public void setNsjg(Double nsjg) {
        this.nsjg = nsjg;
    }

    public String getFkfs() {
        return fkfs;
    }

    public void setFkfs(String fkfs) {
        this.fkfs = fkfs;
    }

    public String getFkfsqt() {
        return fkfsqt;
    }

    public void setFkfsqt(String fkfsqt) {
        this.fkfsqt = fkfsqt;
    }

    public String getSfcd() {
        return sfcd;
    }

    public void setSfcd(String sfcd) {
        this.sfcd = sfcd;
    }

    public String getSfcdsm() {
        return sfcdsm;
    }

    public void setSfcdsm(String sfcdsm) {
        this.sfcdsm = sfcdsm;
    }

    public Double getZjfbl() {
        return zjfbl;
    }

    public void setZjfbl(Double zjfbl) {
        this.zjfbl = zjfbl;
    }

    public Double getZjfjg() {
        return zjfjg;
    }

    public void setZjfjg(Double zjfjg) {
        this.zjfjg = zjfjg;
    }

    public Integer getZjffkqx() {
        return zjffkqx;
    }

    public void setZjffkqx(Integer zjffkqx) {
        this.zjffkqx = zjffkqx;
    }

    public Double getWyjbl() {
        return wyjbl;
    }

    public void setWyjbl(Double wyjbl) {
        this.wyjbl = wyjbl;
    }

    public Double getWyj() {
        return wyj;
    }

    public void setWyj(Double wyj) {
        this.wyj = wyj;
    }

    public String getZjfqtsm() {
        return zjfqtsm;
    }

    public void setZjfqtsm(String zjfqtsm) {
        this.zjfqtsm = zjfqtsm;
    }

    public Double getNzjg() {
        return nzjg;
    }

    public void setNzjg(Double nzjg) {
        this.nzjg = nzjg;
    }
}
